package com.bonus.canteen.core.cook.service;

import java.util.List;
import java.util.Set;

import com.bonus.canteen.core.cook.domain.CookRecipe;
import com.bonus.canteen.core.cook.dto.AllocRecipeStallDTO;
import com.bonus.canteen.core.cook.dto.CookRecipeBindDTO;
import com.bonus.canteen.core.cook.dto.CookRecipeDTO;
import com.bonus.canteen.core.cook.dto.CookRecipeDetailDTO;
import com.bonus.canteen.core.cook.vo.AllocRecipeStallVO;
import com.bonus.canteen.core.cook.vo.CookRecipeDetailVO;
import com.bonus.canteen.core.cook.vo.CookRecipeVO;
import org.springframework.web.multipart.MultipartFile;

/**
 * 菜品计划信息Service接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface ICookRecipeService {
    /**
     * 查询菜品计划信息
     * 
     * @param recipeId 菜品计划信息主键
     * @return 菜品计划信息
     */
    public CookRecipe selectCookRecipeByRecipeId(Long recipeId);

    /**
     * 查询菜品计划信息列表
     * 
     * @param cookRecipe 菜品计划信息
     * @return 菜品计划信息集合
     */
    public List<CookRecipe> selectCookRecipeList(CookRecipe cookRecipe);

    //public List<CookRecipeVO> selectCookRecipeList4Current(CookRecipeDTO dto);

    public List<AllocRecipeStallVO> selectCookRecipeList4Current(AllocRecipeStallDTO content);

    public List<CookRecipeDetailVO> getRecipeDetailByDate(CookRecipeDetailDTO dto);

    public List<CookRecipeDetailVO> getRecipeDetail(CookRecipeDetailDTO dto);

    public List<CookRecipeDetailVO> selectTemplateDetailList(CookRecipeDetailDTO dto);

    /**
     * 新增菜品计划信息
     * 
     * @param cookRecipeDTO 菜品计划信息
     * @return 结果
     */
    public int insertCookRecipe(CookRecipeDTO cookRecipeDTO);

    /**
     * 修改菜品计划信息
     * 
     * @param cookRecipeDTO 菜品计划信息
     * @return 结果
     */
    public int updateCookRecipe(CookRecipeDTO cookRecipeDTO);

    public void bindCookRecipe(CookRecipeBindDTO cookRecipeDTO);

    public Set<String> recipeImportDishes(MultipartFile excel, Long recipeId);

    /**
     * 批量删除菜品计划信息
     * 
     * @param recipeIds 需要删除的菜品计划信息主键集合
     * @return 结果
     */
    public int deleteCookRecipeByRecipeIds(Long[] recipeIds);

    /**
     * 删除菜品计划信息信息
     * 
     * @param recipeId 菜品计划信息主键
     * @return 结果
     */
    public int deleteCookRecipeByRecipeId(Long recipeId);
}
